@@ -607,7 +607,7 @@ __END__
 
 =head1 NAME
 
-Tk::ObjScanner - 'A scanner to view an object\'s attribute
+Tk::ObjScanner - a GUI to scan any perl data structure or object
 
 =head1 SYNOPSIS
 
